| makeGrid | R Documentation |
Constructs a grid of values spanning the ranges of the spline covariates
stored in an LMMsolver object.
makeGrid(object, grid)
object |
An |
grid |
A numeric vector specifying the number of grid points for each spline dimension. Its length must equal the number of spline variables. |
For each spline variable, equally spaced values are generated between the
minimum and maximum values of the B-splines. The Cartesian product of these sequences
is returned using expand.grid.
A data frame containing all combinations of grid values for the spline covariates.
## Not run:
## Create a 200 x 300 grid for a two-dimensional spline term
grd <- makeGrid(fit, grid = c(200, 300))
head(grd)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.